//////////////////////////////////////////////////////////////////////
//
// IBM Confidential
//
// OCO Source Materials
//
// The Source code for this program is not published or otherwise
// divested of its trade secrets, irrespective of what has been
// deposited with the U.S. Copyright Office
//
// 5769-SS1
// (C) Copyright IBM Corp. 1997,1998
//
////////////////////////////////////////////////////////////////////////
package com.ibm.as400.demo;

import com.ibm.as400.access.*;
import com.ibm.as400.vaccess.*;
import com.sun.java.swing.*;
import com.sun.java.swing.border.*;
import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import java.beans.*;
import java.io.*;
import java.sql.*;
import java.util.*;
import java.net.*;

public class AS400Demo extends JApplet
                       implements ActionListener
{
    public static final int TOTAL_PANELS = 10;
    public static final int WIDTH = 750;
    public static final int HEIGHT = 550;
    public static final int INITIAL_WIDTH = 400;
    public static final int INITIAL_HEIGHT = 200;

    String sys_;
    String uid_;
    String pwd_;
    AS400 system_;
    boolean isApplet_ = true;
    URL thisURL_;

    Dialog aboutBox_;
    JTabbedPane as400DemoPane_;
    JFrame frame_ = null;
    JMenuItem windowsMenuItem_;
    JMenuItem metalMenuItem_;

    SQLConnection conn_;
    Cursor workingCursor_ = new Cursor(Cursor.WAIT_CURSOR);
    Cursor defaultCursor_ = new Cursor(Cursor.DEFAULT_CURSOR);


    // Needed for applet loading from a browser or appletviewer.
    public AS400Demo() { }
    

    public AS400Demo(String sys, boolean isApplet)
    {
        sys_ = sys;
        isApplet_ = isApplet;
    }
    
    public AS400Demo(String sys, String uid, String pwd, boolean isApplet)
    {
        sys_ = sys;
        uid_ = uid;
        pwd_ = pwd;
        isApplet_ = isApplet;
    }

    public static void main (String[] args)
    {
        AS400Demo as400Demo = null;

        // If a system was not specified, then display help text and
        // exit.
        if (args.length == 1) 
        {
            as400Demo = new AS400Demo(args[0], false);
        }
        else if (args.length == 3)
        {
            as400Demo = new AS400Demo(args[0], args[1], args[2], false);
        }
        else
        {
            System.out.println("Usage: java AS400Demo <system>");
            System.out.println("             (or)");
            System.out.println("       java AS400Demo <system> <userID> <password>");
            return;
        }

        as400Demo.run();
    }

    public void init()
    {
        Button button = new Button("Show AS400 Toolbox Demo");
        button.addActionListener(this);
        getContentPane().setLayout(new FlowLayout());
        getContentPane().add(button);
    }

    
    public void actionPerformed(ActionEvent event)
    {
        thisURL_ = this.getCodeBase();
        System.out.println("this url = " + thisURL_);
        AS400Demo as400Demo = new AS400Demo(thisURL_.getHost(), true);
        as400Demo.setURL(thisURL_);
        as400Demo.run();
    }


    public void setURL(URL thisURL)
    {
        thisURL_ = thisURL;
    }

    
    public void run()
    {
        try {
            // Create an AS400 object.  The system name was passed
            // as the first command line argument.
            if (sys_ == null)
               system_ = new AS400();
            else if(uid_ == null)
               system_ = new AS400(sys_);
            else
               system_ = new AS400(sys_, uid_, pwd_);


            // Create a frame.
            frame_ = new JFrame ();

            // Load the components.
            loadComponents();
        }
        catch (Exception e)
        {
           System.out.println ("Error: " + e.getMessage ());
           if (!isApplet_) {
               System.exit (0);
           }
        }
    }


    private void loadComponents()
    {
        try {
            frame_.setTitle("AS/400 Toolbox Loading In Progress");
            JPanel progressPanel = new JPanel() {
                public Insets getInsets() {
                return new Insets(40,30,20,30);
                }
            };
            progressPanel.setLayout(new BoxLayout(progressPanel, BoxLayout.Y_AXIS));
            frame_.getContentPane().add(progressPanel, BorderLayout.CENTER);
        
            Dimension d = new Dimension(400, 20);
            JLabel progressLabel = new JLabel("Loading, please wait...");
            progressLabel.setAlignmentX(CENTER_ALIGNMENT);
            progressLabel.setMaximumSize(d);
            progressLabel.setPreferredSize(d);
            progressPanel.add(progressLabel);
            progressPanel.add(Box.createRigidArea(new Dimension(1,20)));
        
            JProgressBar progressBar = new JProgressBar();
            progressLabel.setLabelFor(progressBar);
            progressBar.setAlignmentX(CENTER_ALIGNMENT);
            progressBar.setMinimum(0);
            progressBar.setMaximum(AS400Demo.TOTAL_PANELS);
            progressBar.setValue(0);
            progressPanel.add(progressBar);
        
            // show the frame
            frame_.setSize(INITIAL_WIDTH, INITIAL_HEIGHT);
            Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
            frame_.setLocation(screenSize.width/2 - INITIAL_WIDTH/2,
                              screenSize.height/2 - INITIAL_HEIGHT/2);
            frame_.show();
            frame_.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
        
            JTabbedPane as400DemoPane_ = new JTabbedPane();
            int currentProgress = 0;
            
            progressLabel.setText("Loading Title Page");
            JPanel p = new JPanel();
            p.setLayout(new BorderLayout());
            ImageIcon logo = loadImageIcon("jt400_logo.gif", "AS/400 Toolbox");
            String toolboxText = "Access AS/400 data and resources from your Java applets and applications with the AS/400 Toolbox for Java!";
            JLabel logoLabel = new JLabel(toolboxText, logo, JLabel.CENTER);
            logoLabel.setHorizontalTextPosition(JLabel.CENTER);
            logoLabel.setVerticalTextPosition(JLabel.TOP);
            logoLabel.setIconTextGap(10);
            p.add(logoLabel, JLabel.CENTER);          
            as400DemoPane_.addTab("AS/400 Toolbox", p);
            progressBar.setValue(++currentProgress);

            progressLabel.setText("Loading Command Call Example");
            CommandCallMenuItemExample commandCall = new CommandCallMenuItemExample(sys_, true);
            commandCall.setFrame(frame_);
            as400DemoPane_.addTab("Command Call", commandCall);
            progressBar.setValue(++currentProgress);

            progressLabel.setText("Loading Explorer Example");
            AS400Explorer as400Explorer = new AS400Explorer(sys_, true);
            as400Explorer.setFrame(frame_);
            as400DemoPane_.addTab("Explorer", as400Explorer);
            progressBar.setValue(++currentProgress);

            progressLabel.setText("Loading Job List Example");
            VJobListExample jobList = new VJobListExample(sys_, true);
            jobList.setFrame(frame_);
            as400DemoPane_.addTab("Job List", jobList);
            progressBar.setValue(++currentProgress);

            progressLabel.setText("Loading Message Queue Example");
            AS400MessageQueue as400MessageQueue = new AS400MessageQueue(sys_, true);
            as400MessageQueue.setFrame(frame_);
            as400DemoPane_.addTab("Message Queue", as400MessageQueue);
            progressBar.setValue(++currentProgress);

            progressLabel.setText("Loading Printer List Example");
            VPrintersExample printerList = new VPrintersExample(sys_, true);
            printerList.setFrame(frame_);
            as400DemoPane_.addTab("Printer List", printerList);
            progressBar.setValue(++currentProgress);

            progressLabel.setText("Loading Printer Output Example");
            VPrinterOutputExample printerOutput = new VPrinterOutputExample(sys_, true);
            printerOutput.setFrame(frame_);
            as400DemoPane_.addTab("Printer Output", printerOutput);
            progressBar.setValue(++currentProgress);

            progressLabel.setText("Loading Program Call Example");
            ProgramCallButtonExample programCall = new ProgramCallButtonExample(sys_, true);
            programCall.setFrame(frame_);
            as400DemoPane_.addTab("Program Call", programCall);
            progressBar.setValue(++currentProgress);

            progressLabel.setText("Loading SQL Query Builder Example");
            SQLQueryBuilder sqlBuilder = new SQLQueryBuilder(sys_, true);
            sqlBuilder.setFrame(frame_);
            as400DemoPane_.addTab("SQL Builder", sqlBuilder);
            progressBar.setValue(++currentProgress);

            progressLabel.setText("Loading User List Example");
            VUserListExample userList = new VUserListExample(sys_, true);
            userList.setFrame(frame_);
            as400DemoPane_.addTab("User List", userList);
            progressBar.setValue(++currentProgress);

            frame_.getContentPane().removeAll();
            frame_.getContentPane().setLayout(new BorderLayout());
            frame_.getContentPane().add(createMenuBar(), BorderLayout.NORTH);
            frame_.getContentPane().add(as400DemoPane_, BorderLayout.CENTER);
            frame_.setLocation(screenSize.width/2 - WIDTH/2,
                               screenSize.height/2 - HEIGHT/2);        
            frame_.setSize(WIDTH, HEIGHT);
            frame_.setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
            frame_.setTitle("AS/400 Toolbox");
            frame_.validate();
            frame_.repaint();

            // When the frame closes, exit.
            frame_.addWindowListener (new WindowAdapter ()
            {
                public void windowClosing(WindowEvent e)
                {
                    frame_.dispose();
                    system_.disconnectAllServices();
                    if (!isApplet_) {
                        System.exit(0);
                    }
                }
            } );
        }
        catch (Exception e)
        {
            e.printStackTrace();
            System.out.println ("Error: " + e.getMessage ());
            if (!isApplet_) {
                System.exit (0);
            }
        }
    }


    private JMenuBar createMenuBar()
    {
        JMenuBar menuBar = new JMenuBar();
    
        JMenuItem mi;
    
        // File Menu
        JMenu file = (JMenu) menuBar.add(new JMenu("File"));
        file.setMnemonic('F');
        mi = (JMenuItem) file.add(new JMenuItem("About"));
        mi.setMnemonic('t');
        mi.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                if(aboutBox_ == null) {
                    aboutBox_ = new Dialog(frame_, "About AS/400 Toolbox", false);
                    JPanel groupPanel = new JPanel(new BorderLayout());
                    aboutBox_.add(groupPanel, BorderLayout.CENTER);

                    JTextArea text = new JTextArea();
                    text.setText("AS/400 Toolbox for Java is a collection of \nclasses that represent AS/400 data and resources.");
                    groupPanel.add(text, BorderLayout.CENTER);
                    JPanel buttonPanel = new JPanel(true);
                    groupPanel.add(buttonPanel, BorderLayout.SOUTH);
                    JButton button = (JButton) buttonPanel.add(new JButton("OK"));
                    button.addActionListener(new ActionListener() {
                        public void actionPerformed(ActionEvent e) {
                            aboutBox_.setVisible(false);
                        }
                    });
                }
                aboutBox_.pack();
                aboutBox_.show();
            }
        });
    
        file.add(new JSeparator());
        mi = (JMenuItem) file.add(new JMenuItem("Exit"));
        mi.setMnemonic('x');
        mi.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                frame_.dispose();
                system_.disconnectAllServices();
                if (!isApplet_) {
                    System.exit(0);
                }
            }
        });


        // Options Menu
        JMenu options = (JMenu) menuBar.add(new JMenu("Options"));
        options.setMnemonic('p');
    
        // Look and Feel Radio control
        ButtonGroup group = new ButtonGroup();
        ToggleUIListener toggleUIListener = new ToggleUIListener();
        
        // Windows UI
        windowsMenuItem_ = (JRadioButtonMenuItem) options.add(new JRadioButtonMenuItem("Windows Style Look and Feel"));
        windowsMenuItem_.setSelected(UIManager.getLookAndFeel().getName().equals("Windows"));
        group.add(windowsMenuItem_);
        windowsMenuItem_.addItemListener(toggleUIListener);
        windowsMenuItem_.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_1, ActionEvent.ALT_MASK));
    
        // Metal UI
        metalMenuItem_ = (JRadioButtonMenuItem) options.add(new JRadioButtonMenuItem("Metal Look and Feel"));
        metalMenuItem_.setSelected(UIManager.getLookAndFeel().getName().equals("Metal"));
        metalMenuItem_.setSelected(true);
        group.add(metalMenuItem_);
        metalMenuItem_.addItemListener(toggleUIListener);
        metalMenuItem_.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_3, ActionEvent.ALT_MASK));

        return menuBar;
    }


    private ImageIcon loadImageIcon(String fileName, String description) {
        if(!isApplet_) {
            return new ImageIcon(fileName, description);
        }
        else {
            URL url;
            try {
                System.out.println("this url = " + thisURL_);
                url = new URL(thisURL_, fileName);
            }
            catch(Exception e) {
                e.printStackTrace();
                System.err.println("Error trying to load image " + fileName);
                return null;
            }
            return new ImageIcon(url, description);
        }
    }


    /**
     * Switch the user interface between the Windows and the Metal Look and Feel
     */
    class ToggleUIListener implements ItemListener {
    	public void itemStateChanged(ItemEvent e) {
    	    frame_.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
    	    JRadioButtonMenuItem rb = (JRadioButtonMenuItem) e.getSource();
            try {
                if(rb.isSelected() && rb.getText().equals("Windows Style Look and Feel")) {
                    UIManager.setLookAndFeel("com.sun.java.swing.plaf.windows.WindowsLookAndFeel");
                    SwingUtilities.updateComponentTreeUI(frame_);
                }
                else if(rb.isSelected() && rb.getText().equals("Metal Look and Feel")) {
                    UIManager.setLookAndFeel("com.sun.java.swing.plaf.metal.MetalLookAndFeel");
                    SwingUtilities.updateComponentTreeUI(frame_);
                } 
            }
            catch (UnsupportedLookAndFeelException exc) {
                // Error - unsupported L&F
                rb.setEnabled(false);
                System.err.println("Unsupported LookAndFeel: " + rb.getText());
    		
                // Set L&F to Metal
                try {
                    metalMenuItem_.setSelected(true);
                    UIManager.setLookAndFeel(UIManager.getCrossPlatformLookAndFeelClassName());
                    SwingUtilities.updateComponentTreeUI(frame_);
                }
                catch (Exception exc2) {
                    System.err.println("Could not load LookAndFeel: " + exc2);
                }
            }
            catch (Exception exc) {
                rb.setEnabled(false);
                System.err.println("Could not load LookAndFeel: " + rb.getText());
            }

            frame_.setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
    	}

    }


}            

       
