/////////////////////////////////////////////////////////////////////////
//
// VIFSDirectory example.  This program presents a tree view of
// some directories in the integrated file system.
//
// Command syntax:
//    java AS400Explorer system
//
/////////////////////////////////////////////////////////////////////////
//
// This source is an example of AS/400 Toolbox for Java "VIFSDirectory".
// IBM grants you a nonexclusive license to use this as an example
// from which you can generate similar function tailored to
// your own specific needs.
//
// This sample code is provided by IBM for illustrative purposes
// only. These examples have not been thoroughly tested under all
// conditions. IBM, therefore, cannot guarantee or imply
// reliability, serviceability, or function of these programs.
//
// All programs contained herein are provided to you "AS IS"
// without any warranties of any kind.  The implied warranties of
// merchantablility and fitness for a particular purpose are
// expressly disclaimed.
//
// AS/400 Toolbox for Java
// (C) Copyright IBM Corp. 1997, 1998
// All rights reserved.
// US Government Users Restricted Rights -
// Use, duplication, or disclosure restricted
// by GSA ADP Schedule Contract with IBM Corp.
//
/////////////////////////////////////////////////////////////////////////
package com.ibm.as400.demo;

import com.ibm.as400.access.*;
import com.ibm.as400.vaccess.*;
import com.sun.java.swing.*;
import java.applet.*;
import java.awt.*;
import java.awt.event.*;

public class AS400Explorer extends JComponent
{
    String sys_;
    boolean isJComponent_ = true;
    JFrame frame_;

    public AS400Explorer(String sys, boolean isJComponent)
    {
        super();
        sys_ = sys;
        isJComponent_ = isJComponent;
        if (isJComponent_)
            run();
    }


    public static void main (String[] args)
    {
        // If a system was not specified, then display help text and
        // exit.
        if (args.length != 1)
        {
            System.out.println("Usage: java AS400Explorer <system>");
            return;
        }

        AS400Explorer as400Explorer = new AS400Explorer(args[0], false);
        as400Explorer.run();
    }


    public void setFrame(JFrame frame)
    {
        frame_ = frame;
    }


    public void run()
    {
        try
        {
            // Create an AS400 object.  The system name was passed
            // as the first command line argument.
            AS400 system = new AS400 (sys_);

            // Create a VIFSDirectory object which represents the root
            // of the directory tree that we are going to show.
            VIFSDirectory directory = new VIFSDirectory (system, "/");

            if (!isJComponent_) {
                // Create a frame.
                frame_ = new JFrame ("AS400 Explorer Demo");
                // When the frame closes, exit.
                frame_.addWindowListener (new WindowAdapter ()
                {
                    public void windowClosing(WindowEvent e)
                    {
                        frame_.dispose();
                        if (!isJComponent_) {
                            System.exit(0);
                        }
                    }
                } );
            }

            // Create an error dialog adapter.  This will display
            // any errors to the user.
            ErrorDialogAdapter errorHandler = new ErrorDialogAdapter (frame_);

            // Create a tree pane to present the directories hierarchically.
            // Load the information from the system.
            AS400ExplorerPane explorerPane = new AS400ExplorerPane (directory);
            explorerPane.addErrorListener (errorHandler);
            explorerPane.load ();

            if (!isJComponent_) {
                // Layout the frame with the tree pane.
                frame_.getContentPane().setLayout (new BorderLayout ());
                frame_.getContentPane().add ("Center", explorerPane);
                frame_.pack ();
                frame_.show ();
            }
            else {
                setLayout(new BorderLayout());
                add("Center", explorerPane);
            }
        }
        catch (Exception e)
        {
           System.out.println ("Error: " + e.getMessage ());
           if (!isJComponent_)
               System.exit (0);
        }
    }

}
