/////////////////////////////////////////////////////////////////////////
//
// Command call menu item example.  This program demonstrates how to
// use a menu item that calls an AS/400 command.  It will display
// any messages that are returned in a dialog.
//
// Command syntax:
//    CommandCallMenuItemExample system
//
/////////////////////////////////////////////////////////////////////////
//
// This source is an example of AS/400 Toolbox for Java "CommandCallMenuItem".
// IBM grants you a nonexclusive license to use this as an example
// from which you can generate similar function tailored to
// your own specific needs.
//
// This sample code is provided by IBM for illustrative purposes
// only. These examples have not been thoroughly tested under all
// conditions. IBM, therefore, cannot guarantee or imply
// reliability, serviceability, or function of these programs.
//
// All programs contained herein are provided to you "AS IS"
// without any warranties of any kind.  The implied warranties of
// merchantablility and fitness for a particular purpose are
// expressly disclaimed.
//
// AS/400 Toolbox for Java
// (C) Copyright IBM Corp. 1997, 1998
// All rights reserved.
// US Government Users Restricted Rights -
// Use, duplication, or disclosure restricted
// by GSA ADP Schedule Contract with IBM Corp.
//
/////////////////////////////////////////////////////////////////////////
package com.ibm.as400.demo;

import com.ibm.as400.access.*;
import com.ibm.as400.vaccess.*;
import com.sun.java.swing.*;
import java.applet.*;
import java.awt.*;
import java.awt.event.*;

public class CommandCallMenuItemExample extends JComponent
{

    boolean isJComponent_ = true;
    String sys_, uid_, pwd_;
    JFrame frame_;
    private static AS400ListPane listPane;

    public CommandCallMenuItemExample(String sys, boolean isJComponent)
    {
	sys_ = sys;
        isJComponent_ = isJComponent;
        if (isJComponent_)
           run();
    }

    public CommandCallMenuItemExample(String sys, String uid, String pwd, boolean isJComponent)
    {
	sys_ = sys;
	uid_ = uid;
	pwd_ = pwd;
        isJComponent_ = isJComponent;
        if (isJComponent_)
           run();
    }

    public static void main (String[] args)
    {
	CommandCallMenuItemExample commandCall;

	// If a system was not specified, then display help text and
	// exit.
	if (args.length == 1) 
	{
	    commandCall = new CommandCallMenuItemExample(args[0], false);
	}
	else if (args.length == 3)
	{
	    commandCall = new CommandCallMenuItemExample(args[0], args[1], args[2], false);
	}
	else
	{
	    System.out.println("Usage:  CommandCallMenuItemExample system");
	    System.out.println("             (or)");
	    System.out.println("        CommandCallMenuItemExample system userID password");
	    return;
	}
        commandCall.run();
    }

    public void setFrame(JFrame frame)
    {
        frame_ = frame;
    }

    public void run()
    {
	try
	{
	    // Create an AS400 object.
	    AS400 system;
	    if (sys_ == null)
	       system = new AS400();
	    else if(uid_ == null)
	       system = new AS400(sys_);
	    else
	       system = new AS400(sys_, uid_, pwd_);

	    // Create a VIFSDirectory object which represents QSYS
	    VIFSDirectory directory = new VIFSDirectory (system, "/QSYS.LIB");
	    directory.setPattern("*.LIB");

            if (!isJComponent_) {
               // Create a frame
               frame_ = new JFrame ("Command Call Example");
               // When the frame closes, exit.
               frame_.addWindowListener (new WindowAdapter ()
               {
                  public void windowClosing(WindowEvent e)
                  {
                     if (!isJComponent_)
                        frame_.dispose();
                        System.exit(0);
                  }
               } );
            }

	    // Create an error dialog adapter.  This will display
	    // any errors to the user.
	    ErrorDialogAdapter errorHandler = new ErrorDialogAdapter (frame_);

	    // Create the list pane to display the directory
	    listPane = new AS400ListPane (directory);
	    listPane.addErrorListener (errorHandler);
	    listPane.load();

	    // Create a CommandCallMenuItem object to run the command.
	    CommandCallMenuItem crtMenuItem = new CommandCallMenuItem ("Create library TOOLBOX",
		null, system, "CRTLIB TOOLBOX");
	    crtMenuItem.addErrorListener (errorHandler);

	    // Create a CommandCallMenuItem object to run the command.
	    CommandCallMenuItem dltMenuItem = new CommandCallMenuItem ("Delete library TOOLBOX",
		null, system, "DLTLIB TOOLBOX");
	    dltMenuItem.addErrorListener (errorHandler);

	    // Add an action completed listener to display any
	    // returned messages in a dialog.
	    crtMenuItem.addActionCompletedListener (new ActionCompletedListener ()
	    {
		public void actionCompleted (ActionCompletedEvent event)
		{
		    // Get the message list from the event source.
		    CommandCallMenuItem item = (CommandCallMenuItem) event.getSource ();
		    AS400Message[] messageList = item.getMessageList ();

		    // Use an AS/400 details pane to display the messages.
		    VMessageList vmessageList = new VMessageList (messageList);
		    AS400DetailsPane messageDetails = new AS400DetailsPane (vmessageList);
		    messageDetails.load ();

		    // Show the details in a dialog.
		    JOptionPane.showMessageDialog (frame_, messageDetails);

		    // Update the listPane
		    listPane.load();
		}
	    });

	    // Add an action completed listener to display any
	    // returned messages in a dialog.
	    dltMenuItem.addActionCompletedListener (new ActionCompletedListener ()
	    {
		public void actionCompleted (ActionCompletedEvent event)
		{
		    // Get the message list from the event source.
		    CommandCallMenuItem item = (CommandCallMenuItem) event.getSource ();
		    AS400Message[] messageList = item.getMessageList ();

		    // Use an AS/400 details pane to display the messages.
		    VMessageList vmessageList = new VMessageList (messageList);
		    AS400DetailsPane messageDetails = new AS400DetailsPane (vmessageList);
		    messageDetails.load ();

		    // Show the details in a dialog.
		    JOptionPane.showMessageDialog (frame_, messageDetails);

		    // Update the list pane
		    listPane.load();
		}
	    });


	    // Create a menu with the item.
	    JMenu menu = new JMenu ("AS/400 Command Calls");
	    menu.add (crtMenuItem);
	    menu.add (dltMenuItem);

            JMenuBar menuBar = new JMenuBar ();
	    menuBar.add (menu);

            if (!isJComponent_) {
               // Layout the frame with the list pane.
               frame_.getRootPane ().setMenuBar (menuBar);
               frame_.getContentPane ().setLayout (new BorderLayout ());
               frame_.getContentPane ().add("Center", listPane);
               frame_.pack();
               frame_.show ();
            }
            else {
               setLayout (new BorderLayout() );
               add("North", menuBar);
               add("Center", listPane);
            }
	}
	catch (Exception e)
	{
	   System.out.println ("Error: " + e.getMessage ());
           if (!isJComponent_) {
	      System.exit (0);
	   }
	}
    }

}
