/////////////////////////////////////////////////////////////////////////
//
// Program call button example.  This program demonstrates how to
// use a button that calls an AS/400 program.  It will exchange data
// with the AS/400 program via an input and output parameter.
//
// Command syntax:
//    ProgramCallButtonExample system
//
/////////////////////////////////////////////////////////////////////////
//
// This source is an example of AS/400 Toolbox for Java "ProgramCallButton".
// IBM grants you a nonexclusive license to use this as an example
// from which you can generate similar function tailored to
// your own specific needs.
//
// This sample code is provided by IBM for illustrative purposes
// only. These examples have not been thoroughly tested under all
// conditions. IBM, therefore, cannot guarantee or imply
// reliability, serviceability, or function of these programs.
//
// All programs contained herein are provided to you "AS IS"
// without any warranties of any kind.  The implied warranties of
// merchantablility and fitness for a particular purpose are
// expressly disclaimed.
//
// AS/400 Toolbox for Java
// (C) Copyright IBM Corp. 1997, 1998
// All rights reserved.
// US Government Users Restricted Rights -
// Use, duplication, or disclosure restricted
// by GSA ADP Schedule Contract with IBM Corp.
//
/////////////////////////////////////////////////////////////////////////
package com.ibm.as400.demo;

import com.ibm.as400.access.*;
import com.ibm.as400.vaccess.*;
import com.sun.java.swing.*;
import java.applet.*;
import java.awt.*;
import java.awt.event.*;

public class ProgramCallButtonExample extends JComponent
{

    private static ProgramParameter   parm1, parm2, parm3, parm4, parm5;
    private static JLabel              cpuField;
    private static JLabel              dasdField;
    private static JProgressBar       cpuProgress;
    private static JProgressBar       dasdProgress;
    private static JTextField          jobsField;

    String sys_, uid_, pwd_;
    boolean isJComponent_ = true;
    JFrame frame_;

    public ProgramCallButtonExample(String sys, boolean isJComponent)
    {
        sys_ = sys;
        isJComponent_ = isJComponent;
        if (isJComponent_)
           run();
    }

    public ProgramCallButtonExample(String sys, String uid, String pwd, boolean isJComponent)
    {
        sys_ = sys;
        uid_ = uid;
        pwd_ = pwd;
        isJComponent_ = isJComponent;
        if (isJComponent_)
           run();

    }

    public static void main (String[] args)
    {
        ProgramCallButtonExample programCall;

        // If a system was not specified, then display help text and
        // exit.
        if (args.length == 1) 
        {
            programCall = new ProgramCallButtonExample(args[0], false);
        }
        else if (args.length == 3)
        {
            programCall = new ProgramCallButtonExample(args[0], args[1], args[2], false);
        }
        else
        {
            System.out.println("Usage:  ProgramCallButtonExample system");
            System.out.println("             (or)");
            System.out.println("        ProgramCallButtonExample system userID password");
            return;
        }
        programCall.run();
    }

    public void setFrame(JFrame frame)
    {
        frame_ = frame;
    }


    private void addComponents(ProgramCallButton button)
    {
        GridBagLayout layout = new GridBagLayout();
        GridBagConstraints constraints = new GridBagConstraints();
        constraints.fill = GridBagConstraints.BOTH;
        constraints.insets = new Insets(4, 4, 4, 4);
        constraints.gridwidth = 2;
        constraints.gridheight = 2;
        constraints.ipadx = 4;
        constraints.ipady = 4;

        JPanel progressPanel = new JPanel();
        progressPanel.setLayout(layout);


        // Create the 'CPU Utilization:' Label and add to the panel.
        JLabel label = new JLabel("CPU Utilization: ");
        constraints.gridx = 0;
        constraints.gridy = 0;
        layout.setConstraints(label, constraints);
        progressPanel.add(label);

        // Create the CPU Utilization text field and add to the panel.
        cpuProgress = new JProgressBar();
        cpuProgress.setMinimum(0);
        cpuProgress.setMaximum(100);
        constraints.gridx = 2;
        constraints.gridy = 0;
        layout.setConstraints(cpuProgress, constraints);
        progressPanel.add(cpuProgress);

        // Create the percentage label
        cpuField = new JLabel("0  %  ");
        constraints.gridx = 4;
        constraints.gridy = 0;
        layout.setConstraints(cpuField, constraints);
        progressPanel.add(cpuField);

        // Create the 'DASD Utilization:' Label and add to the panel.
        label = new JLabel("DASD Utilization: ");
        constraints.gridx = 0;
        constraints.gridy = 2;
        layout.setConstraints(label, constraints);
        progressPanel.add(label);

        // Create the DASD Utilization text field and add to the panel.
        dasdProgress = new JProgressBar();
        dasdProgress.setMinimum(0);
        dasdProgress.setMaximum(100);
        constraints.gridx = 2;
        constraints.gridy = 2;
        layout.setConstraints(dasdProgress, constraints);
        progressPanel.add(dasdProgress);

        // Create the percentage label
        dasdField = new JLabel("0  %  ");
        constraints.gridx = 4;
        constraints.gridy = 2;
        layout.setConstraints(dasdField, constraints);
        progressPanel.add(dasdField);

        // Construct labels & text fields for 'Total Jobs' & 'Total DASD'.
        label = new JLabel("Number of Active Jobs: ");
        constraints.gridx = 0;
        constraints.gridy = 4;
        layout.setConstraints(label, constraints);
        progressPanel.add(label);

        jobsField = new JTextField(10);
        jobsField.setEditable(false);
        constraints.gridx = 2;
        constraints.gridy = 4;
        layout.setConstraints(jobsField, constraints);
        progressPanel.add(jobsField);

        JPanel buttonPanel = new JPanel();
        buttonPanel.add(button);

        // Put the progressPanel & statusPanel together
        JPanel dataPanel = new JPanel(new BorderLayout());
        dataPanel.add("Center", progressPanel);
        dataPanel.add("South", buttonPanel);

        if (!isJComponent_) {
           frame_.getContentPane().setLayout (new BorderLayout());
           frame_.getContentPane().add ("Center", dataPanel);
           frame_.pack ();
           frame_.show ();
        }
        else
        {
           setLayout(new BorderLayout());
           add ("Center", dataPanel);
        }

    }


    public void run()
    {
        try
        {
            // Create a frame.
            if (!isJComponent_) {
               frame_ = new JFrame ("Program call button example");

               // Listener to close window.
               frame_.addWindowListener(new WindowAdapter()
               {
                  public void windowClosing(WindowEvent e)
                  {
                     if(!isJComponent_) {
                        frame_.dispose();
                        System.exit(0);                        
                     }
                  }
               } );
            }

            // Create an error dialog adapter.  This will display
            // any errors to the user.
            ErrorDialogAdapter errorHandler = new ErrorDialogAdapter (frame_);

            // Create an AS400 object.
            AS400 system;
            if (sys_ == null)
               system = new AS400();
            else if(uid_ == null)
               system = new AS400(sys_);
            else
               system = new AS400(sys_, uid_, pwd_);

            // Create the program path name.
            QSYSObjectPathName programName = new QSYSObjectPathName ("QSYS",
                "QWCRSSTS", "PGM");

            // Create a ProgramCallButton object.  The button
            // will have the text "Refresh" and no icon.
            ProgramCallButton button = new ProgramCallButton ("Refresh", null);
            button.setSystem (system);
            button.setProgram (programName.getPath ());
            button.addErrorListener (errorHandler);

            // The first parameter is an 64 byte output parameter.
            parm1 = new ProgramParameter (64);
            button.addParameter (parm1);

            // We use the second parameter to set the buffer size
            // of the first parameter.  We will always set this to
            // 64.  Remember that we need to convert the Java int
            // value 64 to its AS/400 format.
            AS400Bin4 parm2Converter = new AS400Bin4 ();
            byte[] parm2Bytes = parm2Converter.toBytes (64);
            parm2 = new ProgramParameter (parm2Bytes);
            button.addParameter (parm2);

            // The third parameter is the status format.  We will
            // always use "SSTS0200".  This is a String value, and
            // again we need to convert it to its AS/400 format.
            AS400Text parm3Converter = new AS400Text (8);
            byte[] parm3Bytes = parm3Converter.toBytes ("SSTS0200");
            parm3 = new ProgramParameter (parm3Bytes);
            button.addParameter (parm3);

            // The fourth parameter is the reset statistics parameter.
            // We will always pass "*NO" as a 10 character String.
            AS400Text parm4Converter = new AS400Text (10);
            byte[] parm4Bytes = parm4Converter.toBytes ("*NO       ");
            parm4 = new ProgramParameter (parm4Bytes);
            button.addParameter (parm4);

            // The fifth parameter is for error information.  It
            // is an input/output parameter.  We will not use it
            // for this example, but we need to set it to something,
            // or else the number of parameters will not match
            // what the server is expecting.
            byte[] parm5Bytes = new byte[32];
            parm5 = new ProgramParameter (parm5Bytes, 0);
            button.addParameter (parm5);

            // When the program is called, we need to process the
            // information that comes back in the first parameter.
            // The format of the data in this parameter was documented
            // by the program we are calling.
            button.addActionCompletedListener (new ActionCompletedListener ()
            {
                public void actionCompleted (ActionCompletedEvent event)
                {
                    // Get the data from the first parameter.
                    // It is in AS/400 format.
                    byte[] parm1Bytes = parm1.getOutputData ();

                    // Each of the pieces of data that we need
                    // is an int.  We can create one converter
                    // to do all of our conversions.
                    AS400Bin4 parm1Converter = new AS400Bin4 ();

                    // Get the CPU utilitization starting at byte 32.
                    // Set this value in the corresponding text field.
                    int cpu = parm1Converter.toInt (parm1Bytes, 32);
                    cpuField.setText (Integer.toString (cpu / 10) + " %");
                    cpuProgress.setValue(cpu/10);

                    // Get the DASD utilitization starting at byte 52.
                    // Set this value in the corresponding text field.
                    int dasd = parm1Converter.toInt (parm1Bytes, 52);
                    dasdField.setText (Integer.toString (dasd / 10000) + " %");
                    dasdProgress.setValue(dasd/10000);

                    // Get the number of active jobs starting at byte 36.
                    // Set this value in the corresponding text field.
                    int jobs = parm1Converter.toInt (parm1Bytes, 36);
                    jobsField.setText (Integer.toString (jobs));
                }
            });

            addComponents(button);
        }
        catch (Exception e)
        {
           System.out.println ("Error: " + e.getMessage ());
           if (!isJComponent_) {
              System.exit (0);
           }
        }
    }

}
