//////////////////////////////////////////////////////////////////////
//
// SQLQueryBuilder example.  This program presents an interactive tool
// for dynamically building SQL queries.
//
// Command syntax:
//   java SQLQueryBuilder system
//
////////////////////////////////////////////////////////////////////////
//
// This source is an example of AS/400 Toolbox for Java "SQLQueryBuilder".
// IBM grants you a nonexclusive license to use this as an example
// from which you can generate similar function tailored to
// your own specific needs.
//
// This sample code is provided by IBM for illustrative purposes
// only. These examples have not been thoroughly tested under all
// conditions. IBM, therefore, cannot guarantee or imply
// reliability, serviceability, or function of these programs.
//
// All programs contained herein are provided to you "AS IS"
// without any warranties of any kind.  The implied warranties of
// merchantablility and fitness for a particular purpose are
// expressly disclaimed.
//
// AS/400 Toolbox for Java
// (C) Copyright IBM Corp. 1997, 1998
// All rights reserved.
// US Government Users Restricted Rights -
// Use, duplication, or disclosure restricted
// by GSA ADP Schedule Contract with IBM Corp.
//
/////////////////////////////////////////////////////////////////////////
package com.ibm.as400.demo;

import com.ibm.as400.access.*;
import com.ibm.as400.vaccess.*;
import com.sun.java.swing.*;
import com.sun.java.swing.border.*;
import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import java.beans.*;
import java.io.*;
import java.sql.*;
import java.util.*;

public class SQLQueryBuilder extends JComponent
{
    String sys_;
    boolean isJComponent_ = true;

    SQLQueryBuilderPane panel_;
    SQLResultSetTablePane tablePanel_;
    SQLResultSetFormPane formPanel_;
    JFrame frame_ = null;
    JFrame tableFrame_ = null;
    JFrame formFrame_ = null;
    SQLConnection conn_;
    Cursor workingCursor_ = new Cursor(Cursor.WAIT_CURSOR);
    Cursor defaultCursor_ = new Cursor(Cursor.DEFAULT_CURSOR);


    public SQLQueryBuilder(String sys, boolean isJComponent)
    {
        super();
        sys_ = sys;
        isJComponent_ = isJComponent;
        if (isJComponent_)
            run();
    }


    public static void main (String[] args)
    {
        // If a system was not specified, then display help text and
        // exit.
        if (args.length != 1)
        {
            System.out.println("Usage: java SQLQueryBuilder <system>");
            return;
        }

        SQLQueryBuilder sqlBuilder = new SQLQueryBuilder(args[0], false);
        sqlBuilder.run();
    }


    public void setFrame(JFrame frame)
    {
        frame_ = frame;
    }


    public void run()
    {
        try {
            // Register the AS/400 Toolbox for Java JDBC driver.
            DriverManager.registerDriver(new com.ibm.as400.access.AS400JDBCDriver());

            // JDBC setup and connection using the Toolbox JDBC driver.
            String url = "jdbc:as400://" + sys_;
            conn_ = new SQLConnection(url);

            if (!isJComponent_) {
                // Build GUI.
                frame_ = new JFrame("SQL Query");
                frame_.getContentPane().setLayout(new BorderLayout());

                // Listener to close window.
                frame_.addWindowListener(new WindowAdapter()
                {
                    public void windowClosing(WindowEvent e)
                    {
                        try {
                            if (tableFrame_ != null)
                                tableFrame_.dispose();
                            if (formFrame_ != null)
                                formFrame_.dispose();
                            conn_.close();
                            if (!isJComponent_) {
                                frame_.dispose();
                                System.exit(0);
                            }
                        }
                        catch (Exception e1) {
                            e1.printStackTrace();
                        }
                    }
                } );
            }

            // Create an SQLQueryBuilderPane object.
            panel_ = new SQLQueryBuilderPane(conn_);
            panel_.setBorder(new EmptyBorder(5,5,10,5));

            // Set the schemas for which the tables will be listed for inclusion in the query.
            final String[] libs = new String[] {"QIWS"};
            try {
                panel_.setTableSchemas(libs);
            }
            catch(PropertyVetoException e) {}

            // Load the data needed for the query builder.
            panel_.load();
            panel_.addErrorListener(new ErrorDialogAdapter(frame_));
            panel_.setSize(200,200);  // can only set size so small - then has no effect

            // Add the query builder pane to a frame.
            if (!isJComponent_) {
                frame_.getContentPane().add("Center", panel_);
            }
            else {
                setLayout(new BorderLayout());
                add("Center", panel_);
            }


            // Create a button for displaying results in a table.
            JButton tableButton = new JButton("Results In a Table");
            tableButton.addActionListener(new ActionListener()
            {
                public void actionPerformed(ActionEvent ev)
                {
                    // Return the SQL query.
                    String query = panel_.getQuery();
                    if (!query.equals("")) {
                        // Create a new frame for the table pane.
                        tableFrame_ = new JFrame("Query Results In a Table Pane");
                        tableFrame_.addWindowListener(new WindowAdapter()
                        {
                            public void windowClosing() {
                                tableFrame_.dispose();
                            }
                        } );

                        // Create the table pane object to represent the query results.
                        tablePanel_ = new SQLResultSetTablePane(conn_, query);
                        frame_.setCursor(workingCursor_);

                        // Load the table (This causes the query to be run).
                        tablePanel_.load();
                        // Add the SQLResultSetTablePane to the frame.
                        tableFrame_.getContentPane().add(tablePanel_);
                        tableFrame_.pack();
                        tableFrame_.setSize(650,300);
                        tableFrame_.setResizable(true);
                        tableFrame_.setVisible(true);
                        frame_.setCursor(defaultCursor_);
                    }
                }
            } );

            // Create a button for displaying results in a form.
            JButton formButton = new JButton("Results In a Form");
            formButton.addActionListener(new ActionListener()
            {
                public void actionPerformed(ActionEvent ev)
                {
                    // Return the SQL query.
                    String query = panel_.getQuery();
                    if (!query.equals("")) {
                        // Create a new frame for the form pane.
                        formFrame_ = new JFrame("Query Results In a Form Pane");
                        formFrame_.addWindowListener(new WindowAdapter()
                        {
                            public void windowClosing() {
                                formFrame_.dispose();
                            }
                        } );

                        // Create the form pane object to represents the query results.
                        formPanel_ = new SQLResultSetFormPane(conn_, query);
                        frame_.setCursor(workingCursor_);
                        // Load the table (This causes the query to be run).
                        formPanel_.load();
                        // Add the SQLResultsSetFormPane to the frame.
                        formFrame_.getContentPane().add(formPanel_);
                        formFrame_.pack();
                        formFrame_.setSize(300,450);
                        formFrame_.setResizable(true);
                        formFrame_.setVisible(true);
                        frame_.setCursor(defaultCursor_);
                    }
                }
            } );

            // Add the buttons to the GUI.
            JPanel buttonPanel = new JPanel();
            buttonPanel.add(tableButton);
            buttonPanel.add(formButton);

            if (!isJComponent_) {
                frame_.getContentPane().add("South", buttonPanel);
                frame_.pack();
                frame_.setSize(550,750);
                frame_.setResizable(true);
                frame_.setVisible(true);
            }
            else {
                add("South", buttonPanel);
            }

        }
        catch (Exception e) {
            System.out.println ("Error: " + e.getMessage ());
            if (!isJComponent_)
                System.exit (0);
        }
    }

}
