/////////////////////////////////////////////////////////////////////////
//
// VPrinterOutput example.  This program presents a list of spooled
// files on an AS/400 with an explorer pane.
//
// Command syntax:
//    VPrinterOutputExample system
//
/////////////////////////////////////////////////////////////////////////
//
// This source is an example of AS/400 Toolbox for Java "VPrinterOutput".
// IBM grants you a nonexclusive license to use this as an example
// from which you can generate similar function tailored to
// your own specific needs.
//
// This sample code is provided by IBM for illustrative purposes
// only. These examples have not been thoroughly tested under all
// conditions. IBM, therefore, cannot guarantee or imply
// reliability, serviceability, or function of these programs.
//
// All programs contained herein are provided to you "AS IS"
// without any warranties of any kind.  The implied warranties of
// merchantablility and fitness for a particular purpose are
// expressly disclaimed.
//
// AS/400 Toolbox for Java
// (C) Copyright IBM Corp. 1997, 1998
// All rights reserved.
// US Government Users Restricted Rights -
// Use, duplication, or disclosure restricted
// by GSA ADP Schedule Contract with IBM Corp.
//
/////////////////////////////////////////////////////////////////////////
package com.ibm.as400.demo;

import com.ibm.as400.access.*;
import com.ibm.as400.vaccess.*;
import com.sun.java.swing.*;
import java.applet.*;
import java.awt.*;
import java.awt.event.*;

public class VPrinterOutputExample extends JComponent
{

    String sys_, uid_, pwd_;
    boolean isJComponent_ = true;
    JFrame frame_;

    public VPrinterOutputExample(String sys, boolean isJComponent)
    {
        sys_ = sys;
        isJComponent_ = isJComponent;
        if (isJComponent_)
           run();
    }

    public VPrinterOutputExample(String sys, String uid, String pwd, boolean isJComponent)
    {
        sys_ = sys;
        uid_ = uid;
        pwd_ = pwd;
        isJComponent_ = isJComponent;
        if (isJComponent_)
           run();
    }

    public static void main (String[] args)
    {
        VPrinterOutputExample printerOutput;

        // If a system was not specified, then display help text and
        // exit.
        if (args.length == 1) 
        {
            printerOutput = new VPrinterOutputExample(args[0], false);
        }
        else if (args.length == 3)
        {
            printerOutput = new VPrinterOutputExample(args[0], args[1], args[2], false);
        }
        else
        {
            System.out.println("Usage:  VPrinterOutputExample system");
            System.out.println("             (or)");
            System.out.println("        VPrinterOutputExample system userID password");
            return;
        }
        printerOutput.run();
    }

    public void setFrame(JFrame frame)
    {
        frame_ = frame;
    }

    public void run()
    {
        try
        {

            // Create an AS400 object.
            AS400 system;
            if (sys_ == null)
               system = new AS400();
            else if(uid_ == null)
               system = new AS400(sys_);
            else
               system = new AS400(sys_, uid_, pwd_);

            // Create a VPrinters object which represents the list
            // of printers attached to the system.
            VPrinterOutput output = new VPrinterOutput (system);
            output.setUserFilter(system.getUserId());

            if (!isJComponent_) {
               // Create a frame.
               frame_ = new JFrame ("VPrinterOutput example");

               // Listener to close the window.
               frame_.addWindowListener(new WindowAdapter()
               {
                  public void windowClosing(WindowEvent e)
                  {
                     if (!isJComponent_) {
                        frame_.dispose();
                        System.exit(0);
                     }
                  }
               } );
            }

            // Create an error dialog adapter.  This will display
            // any errors to the user.
            ErrorDialogAdapter errorHandler = new ErrorDialogAdapter (frame_);

            // Create an explorer pane to present the network print resources.
            // Use load to load the information from the system.
            AS400ExplorerPane explorerPane = new AS400ExplorerPane (output);
            explorerPane.addErrorListener (errorHandler);
                    explorerPane.load ();

            if (!isJComponent_) {
               // Layout the frame with the explorer pane.
               frame_.getContentPane ().setLayout (new BorderLayout ());
               frame_.getContentPane ().add ("Center", explorerPane);
               frame_.pack ();
               frame_.show ();
            }
            else {
               setLayout(new BorderLayout ());
               add("Center", explorerPane);
            }
        }
        catch (Exception e)
        {
           System.out.println ("Error: " + e.getMessage ());
           if (!isJComponent_) {
              System.exit (0);
           }
        }
    }
}
