/////////////////////////////////////////////////////////////////////////
//
// VUserList example.  This program presents a list of users on
// a system with an explorer pane and allows selection of one or more
// users.
//
// Command syntax:
//    VUserListExample system
//
/////////////////////////////////////////////////////////////////////////
//
// This source is an example of AS/400 Toolbox for Java "VUserList".
// IBM grants you a nonexclusive license to use this as an example
// from which you can generate similar function tailored to
// your own specific needs.
//
// This sample code is provided by IBM for illustrative purposes
// only. These examples have not been thoroughly tested under all
// conditions. IBM, therefore, cannot guarantee or imply
// reliability, serviceability, or function of these programs.
//
// All programs contained herein are provided to you "AS IS"
// without any warranties of any kind.  The implied warranties of
// merchantablility and fitness for a particular purpose are
// expressly disclaimed.
//
// AS/400 Toolbox for Java
// (C) Copyright IBM Corp. 1997, 1998
// All rights reserved.
// US Government Users Restricted Rights -
// Use, duplication, or disclosure restricted
// by GSA ADP Schedule Contract with IBM Corp.
//
/////////////////////////////////////////////////////////////////////////
package com.ibm.as400.demo;

import com.ibm.as400.access.*;
import com.ibm.as400.vaccess.*;
import com.sun.java.swing.*;
import java.applet.*;
import java.awt.*;
import java.awt.event.*;

public class VUserListExample extends JComponent
{


    JFrame frame_;
    private static AS400ExplorerPane pane;
    String sys_, uid_, pwd_;
    boolean isJComponent_ = true;

    public VUserListExample(String sys, boolean isJComponent)
    {
        sys_ = sys;
        isJComponent_ = isJComponent;
        if (isJComponent_)
           run();
    }

    public VUserListExample(String sys, String uid, String pwd, boolean isJComponent)
    {
        sys_ = sys;
        uid_ = uid;
        pwd_ = pwd;
        isJComponent_ = isJComponent;
        if (isJComponent_)
           run();
    }

    public static void main (String[] args)
    {
        VUserListExample userList;

        // If a system was not specified, then display help text and
        // exit.
        if (args.length == 1) 
        {
            userList = new VUserListExample(args[0], false);
        }
        else if (args.length == 3)
        {
            userList = new VUserListExample(args[0], args[1], args[2], false);
        }
        else
        {
            System.out.println("Usage:  VUserListExample system");
            System.out.println("             (or)");
            System.out.println("        VUserListExample system userID password");
            return;
        }
        userList.run();
    }

    public void setFrame(JFrame frame)
    {
        frame_ = frame;
    }

    public void run()
    {
        try
        {
            // Create an AS400 object.
            AS400 system;
            if (sys_ == null)
               system = new AS400();
            else if(uid_ == null)
               system = new AS400(sys_);
            else
               system = new AS400(sys_, uid_, pwd_);

            // Create a VUserList.  This represents a list of users
            // for use in the Explorer pane.
            VUserList userList = new VUserList (system);

            if (!isJComponent_) {
               // Create a frame.
               frame_ = new JFrame ("VUserList example");
               
               // Listener to close the window.
               frame_.addWindowListener(new WindowAdapter()
               {
                  public void windowClosing(WindowEvent e)
                  {
                     if (!isJComponent_) {
                        frame_.dispose();
                        System.exit(0);
                     }
                  }
               } ); 
            }

            // Create an error dialog adapter.  This will display
            // any errors to the user.
            ErrorDialogAdapter errorHandler = new ErrorDialogAdapter (frame_);

            // Create a explorer pane to display the user list.
            // Use load to load the information from the system.
            pane = new AS400ExplorerPane (userList);
            pane.addErrorListener (errorHandler);
            pane.load ();

            // Layout the frame with the explorer pane.
            if (!isJComponent_)
            {
               frame_.getContentPane ().setLayout (new BorderLayout ());
               frame_.getContentPane ().add ("Center", pane);
               frame_.pack ();
               frame_.show ();
            }
            else {
               setLayout(new BorderLayout());
               add("Center", pane);
            }
        }
        catch (Exception e)
        {
           System.out.println ("Error: " + e.getMessage ());
           if (!isJComponent_) {
              System.exit (0);
           }
        }
    }


    private static void reportSelectedUsers ()
    {
        VObject[] selectedUsers = pane.getSelectedObjects ();

        if (selectedUsers.length == 0)
            System.out.println ("No users were selected.");
        else
        {
            System.out.println ("The selected users were:");
            for (int i = 0; i < selectedUsers.length; ++i)
                System.out.println (selectedUsers[i]);
        }
    }

}
